@@ -113,6 +113,9 @@ impl Record {
         let stop_time: NaiveDateTime = stop_time.extract()?;
         let stop_time = Utc.from_utc_datetime(&stop_time.into());
         self_.inner.stop_time = Some(stop_time);
+        if let Some(start_time) = self_.inner.start_time.as_ref() {
+            self_.inner.runtime = Some((stop_time - *start_time).num_seconds())
+        }
         Ok(self_)
     }
 
@@ -133,9 +136,9 @@ impl Record {
             .map(|components| components.iter().cloned().map(Component::from).collect())
     }
 
-    /// Returns the meta dict
+    /// Returns the meta object
     ///
-    /// Returns None if no meta is available, otherwise returns a dict of meta information.
+    /// Returns None if no meta is available, otherwise returns a meta object.
     #[getter]
     fn meta(&self) -> Option<Meta> {
         self.inner.meta.clone().map(Meta::from)
@@ -164,6 +167,11 @@ impl Record {
     fn runtime(&self) -> Option<i64> {
         self.inner.runtime
     }
+
+    /// Output content of Record as JSON-encoded string
+    fn to_json(&self) -> Result<String, Error> {
+        Ok(format!("{}", serde_json::to_value(&self.inner)?))
+    }
 }
 
 #[pyproto]
